Learn R Programming

RSEIS (version 3.6-8)

getvertsorder: Get Order of Picks from P-wave Arrivals

Description

Uses a Pickfile and the Waveform file, and creates a vector ordering the waveforms by P-wave arrival.

Usage

getvertsorder(P, GU)

Arguments

P
Pickfile Structure
GU
Waveform structure

Value

list:

Details

Waveforms structure may already have pickfile, but this is overridden by input pickfile P.

See Also

swig

Examples

Run this code
data(GH)

vertord <-  getvertsorder(GH$pickfile, GH)

swig(GH,  sel=vertord$sel, WIN=vertord$win,   SHOWONLY=TRUE)


Run the code above in your browser using DataLab