Learn R Programming

RSEIS (version 4.0-3)

plotGH: Plot a seismic trace.

Description

Quick and dirty plot of a seismic trace as recorded and save using stream2GHnosens or other RSEIS savers.

Usage

plotGH(h)

Arguments

h

This is a standard GH object as defined in RSEIS

Value

Side effects

Details

The code converts the amp component to a ts object.

See Also

RSEIS::prepSEIS, RSEIS::prep1wig, RSEIS::PLOT.SEISN, RSEIS::swig

Examples

Run this code
# NOT RUN {
zh = JGET.seis(file='file.RDATA', kind=-1)
plotGH(zh)

# }
# NOT RUN {


# }

Run the code above in your browser using DataLab