Learn R Programming

RSEIS (version 3.5-2)

segy2rseis: Read in multiple segy files.

Description

Read in multiple segy files, and create a list of seismic traces.

Usage

segy2rseis(fnames, Iendian = 1, HEADONLY = FALSE, BIGLONG = FALSE, PLOT = -1, RAW = FALSE) sac2rseis(fnames, Iendian = 1, HEADONLY = FALSE, BIGLONG = FALSE, PLOT = -1, RAW = FALSE)

Arguments

fnames
character vector of file names.
Iendian
Endian-ness of the files
HEADONLY
logical, TRUE=read only the header information. default=FALSE
BIGLONG
logical, indicating whether long is 8 or 4 bytes.
PLOT
logical, TRUE = plot traces
RAW
logical, TRUE=do not convert data to volts

Value

List of seismic traces.

Details

Segy format files are in integer format. The time series ususally represents counts recorded in a data acquisition system. The header includes meta-data and other identifying information.

See Also

read1sac, read1segy, sac2rseis, prepSEIS

Examples

Run this code
## Not run: 
# 
# fnames =
# list.files(path="./SEISMIC_DATA/KARYMSKY/1999/kar99/Day254",
# pattern="", full.names=TRUE )
# 
# MANY = segy2rseis(fnames, Iendian=1 , HEADONLY=FALSE,
#     BIGLONG=FALSE,  PLOT=1, RAW=FALSE )
# 
# 
# ## End(Not run)

Run the code above in your browser using DataLab