Learn R Programming

RSEIS (version 3.6-8)

symshot1: Simulate a seismic shot

Description

Simulate an exploration style seismic shot with ground roll, air wave, refractions and reflections.

Usage

symshot1(PLOT = FALSE)

Arguments

PLOT
logical, TRUE=plot the wiggles. DEFAULT=FALSE

Value

Details

Arrivals are calculated based on geometric considerations with a 1D layered model.

References

Sherrif

See Also

wiggleimage, symshot

Examples

Run this code

S1 <- symshot1()
wiggleimage(S1$smograms, dt = -S1$dt, dx = S1$x, col = "black")


Run the code above in your browser using DataLab