Learn R Programming

RSEIS (version 3.5-2)

travel.time1D: Seismic Travel Time 1D

Description

Travel time from source to reciever in 1D local model.

Usage

travel.time1D(indelta, inhpz, instaz, inlay, ztop, vel) many.time1D(indelta, inhpz, instaz, inlay, ztop, vel)

Arguments

indelta
distance in KM
inhpz
depth of hypocenter, km
instaz
elevation of station
inlay
number of layers
ztop
vector, tops of layers
vel
vector, velocities in layers

Value

list:
dtdr
derivative of t w.r.t. horizontal distance
dtdz
derivative of t w.r.t. z, depth
angle
incidence angle, degrees
tt
travel time, s

Details

Uses local 1D velocity model, not appropriate for spherical earth. The many.time1D version will take a vector of distances (indelta) and either one station elevation or a vector.

The station elevation should be referenced to the top of the velocity model, not necessarily sea level. Usually this is set to zero and a station correction is used to take into account the topographic and other geologic effects.

See Also

Ray.time1D, Get1Dvel

Examples

Run this code


data(VELMOD1D)

v <- VELMOD1D

tees <- travel.time1D(23, 7, 0, length(v$zs) , v$zp , v$vp)

print(tees)

Run the code above in your browser using DataLab