Learn R Programming

RSEIS (version 3.5-2)

tung.pulse: Volcanic Pulse Analysis

Description

given a seiries of pulses, do analysis on each one

Usage

tung.pulse(r, q, dt)

Arguments

r
x-coordinates
q
y-coordinates
dt
deltat, sample interval

Value

vector=c(Ex[1], Ex[2], Ey[1], Ey[2], Cx, Cy, ar2, DefInt[1], DefInt[2], sum0) where:
Ex
left minimum
Ey
right minimum
Cx, Cy
center (max?)
ar2
area of triangle
DefInt[1]
integral under curve
DefInt[2]
integral under curve ( bottom triangle removed)
sum0
RMS amplitude

Details

Calculates, min, max of edges and center, then models the pulse with a triangular pulse and integegrates.

See Also

peaks

Examples

Run this code

## Not run: 
# data(CE1)
# 
# ex <- CE1$x[CE1$x>5.453291 &CE1$x< 5.507338]
# why <- CE1$y[CE1$x>5.453291 &CE1$x< 5.507338]
# plot(ex, why, type='l')
# tung.pulse(ex, why, CE1$dt)
# ## End(Not run)


Run the code above in your browser using DataLab