powered by
Quick and dirty plot of a seismic trace as recorded and save using stream2GHnosens or other RSEIS savers.
plotGH(h)
This is a standard GH object as defined in RSEIS
Side effects
The code converts the amp component to a ts object.
RSEIS::prepSEIS, RSEIS::prep1wig, RSEIS::PLOT.SEISN, RSEIS::swig
# NOT RUN { zh = JGET.seis(file='file.RDATA', kind=-1) plotGH(zh) # } # NOT RUN { # }
Run the code above in your browser using DataLab